==> taalc-0.1.19.tar.gz: taalc-0.1.19/TAALC/teest/tester.py <==
from aiogram import Bot, Dispatcher
from aiogram.types import Message, Update
from ..taalc_bot import TaalcBot
import asyncio
from .bot_response import BotResponse

class Tester:
    bot: Bot
    test_chat_id: int
    dsp: Dispatcher
    tested_bot: TaalcBot
    response: BotResponse
    msg_event: asyncio.Event
    waiting_delay: int

    
    async def handler(self, message: Message):
        msg_user = message.from_user
        if msg_user.is_bot and message.chat.id == self.test_chat_id and \
              msg_user.id == self.tested_bot.bot.id and not self.msg_event.is_set():
                
            self.response.response = message
            self.response.is_responded = True
            self.msg_event.set()

    async def reply(self, replied_msg: Message, msg_text: str, parse_mode: str=None) -> BotResponse:
        sent_msg = await self.bot.send_message(self.test_chat_id, msg_text, \
                            reply_to_message_id=replied_msg.message_id, parse_mode=parse_mode)
        return self._msg(sent_msg, parse_mode)

    async def msg(self, msg_text: str, parse_mode: str=None) -> BotResponse:
        sent_msg = await self.bot.send_message(self.test_chat_id, msg_text, parse_mode=parse_mode)
        return self._msg(sent_msg, parse_mode)

    async def _msg(self, sent_msg: Message, parse_mode: str=None) -> BotResponse:
        

        self.response = BotResponse(sent_msg)
        self.msg_event = asyncio.Event()        
        
        async def waiter():
            await asyncio.sleep(self.waiting_delay)
            self.msg_event.set()

        self.dsp.message()(self.handler)
        asyncio.create_task(self.dsp.start_polling(self.bot, skip_updates=True))
        asyncio.create_task(waiter())
        upd = Update(update_id=1, message=sent_msg)
        await self.tested_bot.dsp.feed_update(self.tested_bot.bot, upd)
        # asyncio.gather(self.dsp.start_polling(self.bot, skip_updates=True), self.tested_bot._start())

        
        await self.msg_event.wait()
        # await asyncio.sleep(3)
        await self.dsp.stop_polling()
        self.dsp.message.handlers.clear()

        return self.response
        

    def __init__(self, tester_bot_token: str, tested_bot: TaalcBot, test_chat_id: int,\
                 waiting_delay=3):
        
        self.bot = Bot(tester_bot_token)
        self.test_chat_id = test_chat_id
        self.dsp = Dispatcher()
        self.tested_bot = tested_bot
        self.waiting_delay = waiting_delay

        
        TaalcBot.testers.append(self)

==> taalc-0.1.20.tar.gz: taalc-0.1.20/TAALC/teest/tester.py <==
from aiogram import Bot, Dispatcher
from aiogram.types import Message, Update
from ..taalc_bot import TaalcBot
import asyncio
from .bot_response import BotResponse

class Tester:
    bot: Bot
    test_chat_id: int
    dsp: Dispatcher
    tested_bot: TaalcBot
    response: BotResponse
    msg_event: asyncio.Event
    waiting_delay: int

    
    async def handler(self, message: Message):
        msg_user = message.from_user
        if msg_user.is_bot and message.chat.id == self.test_chat_id and \
              msg_user.id == self.tested_bot.bot.id and not self.msg_event.is_set():
                
            self.response.response = message
            self.response.is_responded = True
            self.msg_event.set()

    async def reply(self, replied_msg: Message, msg_text: str, parse_mode: str=None) -> BotResponse:
        sent_msg = await self.bot.send_message(self.test_chat_id, msg_text, parse_mode=parse_mode)
        sent_msg = Message(
            text = sent_msg.text,
            message_id = sent_msg.message_id,
            date = sent_msg.date,
            chat = sent_msg.chat,
            message_thread_id = sent_msg.message_thread_id,
            from_user = sent_msg.from_user,
            via_bot = sent_msg.via_bot,
            reply_to_message = replied_msg
        )
        
        res = await self._msg(sent_msg, parse_mode)
        return res

    async def msg(self, msg_text: str, parse_mode: str=None) -> BotResponse:
        sent_msg = await self.bot.send_message(self.test_chat_id, msg_text, parse_mode=parse_mode)
        return await self._msg(sent_msg, parse_mode)

    async def _msg(self, sent_msg: Message, parse_mode: str=None) -> BotResponse:
        

        self.response = BotResponse(sent_msg)
        self.msg_event = asyncio.Event()        
        
        async def waiter():
            await asyncio.sleep(self.waiting_delay)
            self.msg_event.set()

        self.dsp.message()(self.handler)
        asyncio.create_task(self.dsp.start_polling(self.bot, skip_updates=True))
        asyncio.create_task(waiter())
        upd = Update(update_id=1, message=sent_msg)
        await self.tested_bot.dsp.feed_update(self.tested_bot.bot, upd)
        # asyncio.gather(self.dsp.start_polling(self.bot, skip_updates=True), self.tested_bot._start())

        
        await self.msg_event.wait()
        # await asyncio.sleep(3)
        await self.dsp.stop_polling()
        self.dsp.message.handlers.clear()

        return self.response
        

    def __init__(self, tester_bot_token: str, tested_bot: TaalcBot, test_chat_id: int,\
                 waiting_delay=3):
        
        self.bot = Bot(tester_bot_token)
        self.test_chat_id = test_chat_id
        self.dsp = Dispatcher()
        self.tested_bot = tested_bot
        self.waiting_delay = waiting_delay

        
        TaalcBot.testers.append(self)
